@@ -57,6 +57,15 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.addinstrumentbutton,
 			QtCore.SIGNAL("clicked()"),
 			self.add_instrument)
+		self.connect(self.ui.removeblock,
+			QtCore.SIGNAL("clicked()"),
+			self.remove_block)
+		self.connect(self.ui.removeinstrument,
+			QtCore.SIGNAL("clicked()"),
+			self.remove_instrument)
+		self.connect(self.ui.removeprogression,
+			QtCore.SIGNAL("clicked()"),
+			self.remove_progression)
 
 	def set_defaults(self):
 		self.ui.resolution.setCurrentIndex(3) # '8'
@@ -65,14 +74,29 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 	def add_block(self):
 		self.ui.blocks.addItem(self.ui.blockcombo.currentText())
 
+	def remove_block(self):
+		i = self.ui.blocks.currentRow()
+		if i >= 0:
+			self.ui.blocks.takeItem(i)
+
 	def add_progression(self):
 		self.ui.progressions.addItem(
 			self.ui.progressioncombo.currentText())
 
+	def remove_progression(self):
+		i = self.ui.progressions.currentRow()
+		if i >= 0:
+			self.ui.progressions.takeItem(i)
+
 	def add_instrument(self):
 		self.ui.instruments.addItem(
 			self.ui.instrumentcombo.currentText())
 
+	def remove_instrument(self):
+		i = self.ui.instruments.currentRow()
+		if i >= 0:
+			self.ui.instruments.takeItem(i)
+
 	def get_file_name(self, name, n = 0):
 		if n == 0:
 			midi = name + ".mid"
@@ -89,7 +113,6 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			res += str(self.ui.instruments.item(x).text()) + ","
 		if res == "":
 			return None
-		print res
 		return res[:-1]
 
 	def get_progressions(self):
@@ -119,18 +142,22 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		o.instrument = self.get_instruments()
 		o.progression = self.get_progressions()
 		o.blocks = self.get_blocks()
-		print o.bpm
 		project = str(self.ui.projectname.text())
 		if project == "":
 			project = "Untitled"
 		o.midifile = self.get_file_name(project)
 
+
 		try:
 			seq = Options.get_sequencer(o)
+			self.ui.stopbutton.setEnabled(True)
+			self.ui.startbutton.setEnabled(False)
 			seq.play()
 		except Options.OptionError, err:
 			print err
 
+		self.ui.startbutton.setEnabled(True)
+		self.ui.stopbutton.setEnabled(False)
 
 app = QtGui.QApplication(argv)
 i = ImproviserMainWindow()
